autofs-5.1.6 - update sss timeout documentation

From: Ian Kent <raven@themaw.net>

Update then man page documentation and the configuration file
comments to reflect the changes to map reading and key lookups
with the sss lookup module.
---
 CHANGELOG                      |    1 +
 man/autofs.conf.5.in           |   20 +++++++++++++-------
 redhat/autofs.conf.default.in  |   26 ++++++++++++++++++--------
 samples/autofs.conf.default.in |   26 ++++++++++++++++++--------
 4 files changed, 50 insertions(+), 23 deletions(-)

diff --git a/CHANGELOG b/CHANGELOG
index b6522423..817f0154 100644
--- a/CHANGELOG
+++ b/CHANGELOG
@@ -33,6 +33,7 @@ xx/xx/2020 autofs-5.1.7
 - sss introduce calculate_retry_count() function.
 - move readall into struct master.
 - sss introduce a flag to indicate map being read.
+- update sss timeout documentation.
 
 07/10/2019 autofs-5.1.6
 - support strictexpire mount option.
diff --git a/man/autofs.conf.5.in b/man/autofs.conf.5.in
index 39239d4e..8827e762 100644
--- a/man/autofs.conf.5.in
+++ b/man/autofs.conf.5.in
@@ -31,9 +31,11 @@ overrides this and sets the timeout to 5 minutes to be consistent
 with earlier autofs releases.
 .TP
 .B master_wait
-sets the default maximum time to wait for the master map to become
-available if it cannot be read at program start (program default 10,
-wait for 10 seconds then continue).
+Sets the default maximum number of retries (actaul iterations is half
+this, each is delayed by 2 seconds before retrying) waiting for the
+master map to become available if it cannot be read at program start
+(program default 10, then continue). This can be longer if the map
+source itself waits for availability (such as sss).
 .TP
 .B negative_timeout
 .br
@@ -159,10 +161,14 @@ behaviour and so is an opt-in setting.
 .TP
 .B sss_master_map_wait
 .br
-Set the time to wait and retry if sssd returns "no such entry" when starting
-up. When sssd is starting up it can sometimes return "no such entry" for a
-short time until it has read in the LDAP map information. Default is 0 seconds,
-don't wait.
+Set the time to wait and retry if sssd is unable to read the master map
+at program start. Program default is 0 (don't wait) or 10 if sss supports
+returning EHSTDOWN when the provider isn't available.
+
+If the sss library supports returning EHOSTDOWN when the provider is down
+then this value is how long to wait between retries reading the master map.
+When reading dependent maps or looking up a map key this value is multiplied
+by the number of retries that would be used when reading the master map.
 .TP
 .B use_mount_request_log_id
 .br
diff --git a/redhat/autofs.conf.default.in b/redhat/autofs.conf.default.in
index 09bb5dd2..7595b3d8 100644
--- a/redhat/autofs.conf.default.in
+++ b/redhat/autofs.conf.default.in
@@ -14,10 +14,13 @@
 #
 timeout = 300
 #
-# master_wait - set the default maximum time to wait for the
-# 		master map to become available if it cannot
-# 		be read at program start (default 10, wait
-# 		for 10 seconds then continue).
+# master_wait - set the default maximum number of retries (actual
+# 		iterations is half this, each is delayed by 2 seconds
+# 		before retrying) waiting for the master map to become
+# 		available if it cannot be read at program start
+# 		(default 10, then continue). This can be longer
+# 		if the map source itself waits for availability
+# 		(such as sss).
 #
 #master_wait = 10
 #
@@ -195,10 +198,17 @@ mount_nfs_default_protocol = 4
 # sss_master_map_wait - When sssd is starting up it can sometimes return
 #			"no such entry" for a short time until it has read
 # 			in the LDAP map information. Internal default is 0
-# 			seconds, don't wait but if there is a problem with
-# 			autofs not finding the master map at startup (when
-# 			it should) then try setting this to 10 to work
-# 			around it.
+# 			(don't wait) or 10 if sss supports returning EHSTDOWN.
+# 			If there is a problem with autofs not finding the
+# 			master map at startup (when it should) then try setting
+# 			this to 10 or more. If the sss library supports returning
+# 			EHOSTDOWN when the provider is down then this value
+# 			is how long to wait between retries reading the
+# 			master map. When reading dependent maps or looking
+# 			up a map key this value is multiplied by the number
+# 			of retries that would be used when reading the master
+# 			map. (Default, 0 or 10 if sss suppprts returning
+# 			EHOSTDOWN).
 #
 #sss_master_map_wait = 0
 #
diff --git a/samples/autofs.conf.default.in b/samples/autofs.conf.default.in
index 4a18f6fe..e471de7d 100644
--- a/samples/autofs.conf.default.in
+++ b/samples/autofs.conf.default.in
@@ -14,10 +14,13 @@
 #
 timeout = 300
 #
-# master_wait - set the default maximum time to wait for the
-# 		master map to become available if it cannot
-# 		be read at program start (default 10, wait
-# 		for 10 seconds then continue).
+# master_wait - set the default maximum number of retries (actual
+# 		iterations is half this, each is delayed by 2 seconds
+# 		before retrying) waiting for the master map to become
+# 		available if it cannot be read at program start
+# 		(default 10, then continue). This can be longer
+# 		if the map source itself waits for availability
+# 		(such as sss).
 #
 #master_wait = 10
 #
@@ -194,10 +197,17 @@ browse_mode = no
 # sss_master_map_wait - When sssd is starting up it can sometimes return
 #			"no such entry" for a short time until it has read
 # 			in the LDAP map information. Internal default is 0
-# 			seconds, don't wait but if there is a problem with
-# 			autofs not finding the master map at startup (when
-# 			it should) then try setting this to 10 to work
-# 			around it.
+# 			(don't wait) or 10 if sss supports returning EHSTDOWN.
+# 			If there is a problem with autofs not finding the
+# 			master map at startup (when it should) then try setting
+# 			this to 10 or more. If the sss library supports returning
+# 			EHOSTDOWN when the provider is down then this value
+# 			is how long to wait between retries reading the
+# 			master map. When reading dependent maps or looking
+# 			up a map key this value is multiplied by the number
+# 			of retries that would be used when reading the master
+# 			map. (Default, 0 or 10 if sss suppprts returning
+# 			EHOSTDOWN).
 #
 #sss_master_map_wait = 0
 #
